globals
[
 teachers         ;;agentset of all turtles with age = 1 
 meank            ;;mean of the number of naive learners taught per time step
 sumMeank         ;;running tally of the mean number of naive learners taught per time step
 meanMeank        ;;sumMeank / ticks
 Vk               ;;variance in the number of naive learners taught per time step
 sumVk            ;;running tally of variance in the number of naive learners taught per time step
 meanVk           ;;sumVk / ticks
 sumNumTeachers   ;;running tally of the number of teachers per tick 
 meanNumTeachers  ;;sumNumTeachers / ticks
 numTeachers      ;;number of individuals who passed on their variant during the current time step
 xMax             ;;the maximum x value in the parent generation of each time step
]


turtles-own
[
 x                ;;continuously varying cultural trait (e.g., skill level as in Henrich (2004))
 age              ;;0=naive learner, 1=member of the parent/teacher generation
 times-taught     ;;the number of naive individuals taught by ego per time step
 parent           ;;ego's parent 
]


to setup
 clear-all
  
 random-seed seed  ;;set random seed

 ;;initialize data to be collected at the end of each run
 set sumNumTeachers 0 
 set meanNumTeachers 0
 set meank 0 
 set sumMeank 0 
 set meanMeank 0 
 set Vk 0 
 set sumVk 0 
 set meanVk 0 
    
  crt N            ;;create starting population of size N
  [
   set x 0                        ;;all individuals display x = 0 at the start of the simulation
   setxy random-xcor random-ycor  ;;the model is not spatially explicit, so agents are randomly assigned coordinates
   set color x
   set age 0                      
   set times-taught 0
  ]
  
  reset-ticks

end                ;;end of "setup"




to go
  
  tick            ;;"time" passes, each tick represents one discrete and non-overlapping "generation" of social learning
  
  ;;#1 Age: The previously naive generation becomes the experienced generation...
  ask turtles [set age 1]
  ;;and, as such, they are labelled as potential teachers...
  set teachers turtles with [age = 1]
  ;;and the maximum x value among the teacher generation is recorded for use in calculating relative fitness below.
  set xMax max [x] of teachers
  
  ;;#2 Stage 1 of cultural transmission: create naive generation and transmit x vertically from single parent to offspring
  vertical-cultural-transmission

  ;;#3 Stage 2 of cultural transmission: allow for proportion z of the offspring generation to engage in one of two versions of directly biased cultural transmission in place of vertical transmission. This stage also incldues copy error for both vertical and oblique transmission.
  directly-biased-cultural-transmission
     
  ;;#4 Update data to be collected at the end of the simulation
  update-data
  
  ;;#5 Cull the experienced generation
  ask turtles with [age = 1] [die]
  
  ;;#6 Plot mean and max trait values
  plot-data

end               ;;end of "go"


to vertical-cultural-transmission  ;;this method creates a naive generation of size N in the absence or presence of natural selection and operationalizes vertical transmission of x from parent to offspring
  
 ifelse natural-selection = False   ;;create naive generation in the absence of natural selection 
  [
   while [count turtles with [age = 0] < N]   ;;while the size of the naive generation is less than N
   [ 
    ask one-of teachers  ;;randomly chose a member of the teacher generation to serve as a parent
    [;;in the absence of selection, every individual chosen reproduces with prob 1, regardless of its trait value
     set times-taught times-taught + 1  ;;increment number of times taught    
     hatch 1      ;;give birth to 1 new offspring
       [
       set age 0
       setxy random-xcor random-ycor
       set times-taught 0
       set parent myself
       ;;note that by using "hatch" the offspring inherits the parent's x value--this is uniparental vertical transmission
       ]
    ] 
   ]
  ]
  [;;else natural-selection = TRUE. Create naive generation of N individuals in the presence of natural selection.
   while [count turtles with [age = 0] < N]  ;;while the size of the naive generation is less than N
   [ 
    ask one-of teachers  ;;randomly chose a member of the teacher generation to serve as a potential parent
    [
      if random-float 1 < exp (x - xMax)  ;;individual fitness is calculated relative to the xMax value in the parental population. (trait - xMax) will always be <= 0.
      [
      set times-taught times-taught + 1   ;;increment number of times taught  
      hatch 1   ;;give birth to 1 new offspring
       [
       set age 0
       setxy random-xcor random-ycor
       set times-taught 0
       set parent myself
       ;;note that by using "hatch" the offspring inherits the parent's x value--this is uniparental vertical transmission
       ]
      ]
    ]
   ]
  ]
  
end         ;;end of "vertical-cultural-transmission"



to directly-biased-cultural-transmission  ;;this method defines how x is acquired by one of two versions of directly biased cultural transmission.  This method also operationalizes copying error.
  ;let test-teacher one-of teachers   ;;for testing
  
   ask turtles with [age = 0]   ;;ask each member of the naive generation
   [
    ifelse random-float 1 < z  ;;on average, only proportion z of the naive generation will engage in oblique cultural transmission and proportion 1-z will engage in vertical transmission. 
    [
     let teacher nobody  ;;"teacher" is a local variable that starts out empty and assigned an agent later
     
     ifelse direct-biased-version = "Henrich"  ;;in Henrich's version, naive individuals try to copy the highest trait value in the experienced generation, this eliminates drift in cultural transmission.
     [
      set teacher max-one-of teachers [x] 
      ;;set teacher test-teacher  ;;for testing
     ]
     [ ;;else direct-biased-version = "Shennan"  In Shennan's version, ego tries to copy the highest trait value displayed amoung a subset of 5 randomly chosen members of the parent generation excluding ego's biological parent.
     let my-parent parent 
     ;;Here, we need to take the parent out of the possible-teachers, so that social learning is always oblique sensu stricto.
     ;;show "my-parent is:"    ;;for testing
     ;;show [who] of my-parent  ;;for testing
     let possible-teachers teachers with [who != [who] of my-parent]  ;;remove the biological parent from possible-teachers before choosing a teacher, as in Shennan's model
     ;;show "Here are my possible teachers:"   ;;for testing
     ;;show [who] of possible-teachers  ;;for testing
    
     if 5 < count possible-teachers
      [
       set possible-teachers n-of 5 possible-teachers ;;create subset of 5 randomly chosen possbile-teachers, as in Shennan's model
      ]
     ;;ask possible-teachers [show who]  ;;for testing
     
     set teacher max-one-of possible-teachers [x] ;;this culminates Shennan's version of directly biased oblique cultural transmission
     ;;show "Here are the x values of my possble teachers:"   ;;for testing
     ;;show [x] of possible-teachers  ;;for testing
     ;;show "Here is the x of my teacher:"  ;;for testing
     ;;show [x] of teacher   ;;for testing
     ]
    
    ;;show "Teacher times-taught:"   ;;for testing
    ;;ask teacher [show times-taught]  ;;for testing
    ask teacher [set times-taught times-taught + 1]
    ;;ask teacher [show times-taught]  ;;for testing
    
    ;;show "Parent times-taught:"     ;;for testing
    ;;ask parent [show times-taught]  ;;for testing
    ask parent [set times-taught times-taught - 1]
    ;;ask parent [show times-taught]  ;;for testing
    
    ;;now operationalize copy error for the case where the target value is acquired via oblique transmission
    set x (([x] of teacher - alpha) - (beta * ln(random-exponential 1)))  ;;learn from teacher with x value ultimately obtained from the Gumbel distribution
    set color x
    ]
    
    [;;else ego learns vertically from its biological parent (i.e., ego's parent is also ego's teacher) rather than obliquely, again with "noise" according to Gumbel distribution
    set x ((x - alpha) - (beta * ln(random-exponential 1)))  ;;recall that offspring automatically inherit x from their parents during stage 1 above (uniparental vertical transmission) 
    set color x
    ]
   
   ]
  
  
end           ;;end of "directly-biased-cultural-transmission"



to update-data
  set numTeachers count turtles with [age = 1 and times-taught > 0]  ;;this is the number of inidividuals who served as a teacher at least once during the current time step (this is similar to "breeding population size" in pop genetics).
  
  set sumNumTeachers (sumNumTeachers + count turtles with [age = 1 and times-taught > 0])  ;;running tally of numTeachers
  set meanNumTeachers (sumNumTeachers / ticks)   ;;average number of Teachers over time
  
  set meank mean [times-taught] of turtles with [age = 1]  ;;this is the mean number of times taught, averaged over all members of the parent generation, including those who did not serve as a teacher at all.
  set sumMeank (sumMeank + meank)      ;;running tally of meank
  set meanMeank (sumMeank / ticks)     ;;average meank over time
  
  set Vk variance [times-taught] of turtles with [age = 1]  ;;this is the variance in the number of times taught per member of the parent generation, including those who did not serve as a teacher at all.
  set sumVk (sumVk + Vk)       ;;running tally of sumVk
  set meanVk (sumVk / ticks)   ;;average Vk over time
  
end



to plot-data  ;;simple line plot of the mean and max x value of the population at the end of each tick
  
  set-current-plot "mean (black) max (red)"
  set-current-plot-pen "mean"
  plot mean [x] of turtles
  set-current-plot-pen "max"
  plot max [x] of turtles
  
end 
@#$#@#$#@
GRAPHICS-WINDOW
237
10
514
308
16
16
8.1
1
10
1
1
1
0
1
1
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
72
10
135
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
5
10
71
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
137
10
200
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
101
46
193
79
alpha
alpha
0
10
4
1
1
NIL
HORIZONTAL

SLIDER
101
81
193
114
beta
beta
0
10
1
1
1
NIL
HORIZONTAL

SLIDER
6
81
98
114
N
N
1
500
10
1
1
NIL
HORIZONTAL

PLOT
607
10
807
160
mean (black) max (red)
time
x (skill level)
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"mean" 1.0 0 -16777216 true "" ""
"max" 1.0 0 -2674135 false "" ""

SLIDER
6
46
98
79
seed
seed
0
100
9
1
1
NIL
HORIZONTAL

MONITOR
521
212
583
257
NIL
meanVk
3
1
11

MONITOR
522
261
622
306
mean # Teachers
meanNumTeachers
0
1
11

MONITOR
520
165
595
210
NIL
meanMeank
3
1
11

SLIDER
6
199
98
232
z
z
0
1
1
.01
1
NIL
HORIZONTAL

MONITOR
519
11
576
56
N
count turtles
0
1
11

MONITOR
519
58
586
103
# Teachers
numTeachers
0
1
11

SWITCH
6
116
151
149
natural-selection
natural-selection
1
1
-1000

CHOOSER
6
152
135
197
direct-biased-version
direct-biased-version
"Shennan" "Henrich"
1

TEXTBOX
347
312
521
330
This model is not spatially explicit.
10
0.0
1

TEXTBOX
649
196
807
289
Directions\n1. Choose settings.\n2. Hit \"setup\".\n3. Hit \"go\" to start sim run.\n4. Hit \"go\" again to stop.\n5. See Tools->BehaviorSpace to run published experiments.
10
0.0
1

@#$#@#$#@
## WHAT IS IT?

premo_2016.nlogo
version 1.0

This model was programmed and run in Netlogo version 5.1. Please keep in mind that the source code may require minor modifications to run in subsequent versions of NetLogo.


## HOW TO USE IT

1. Choose settings.
2. Hit "setup".
3. Hit "go" to start simulation run.
4. Hit "go" again to stop.
5. See Tools->BehaviorSpace to run published experiments for yourself.

## FULL MODEL DESCRIPTION

This description of the agent-based model introduced in Premo (2016) follows the ODD protocol (see Grimm et al. 2010).

PURPOSE
This model illustrates how the effective population size and the rate of change in mean skill level of a cultural trait is affected by the presence of natural selection and/or the cultural transmission mechanism by which it is passed. The model, which combines aspects of Shennan’s (2001) and Henrich’s (2004) influential selection models, is used to address the following research questions:
How does census population size affect the rate of change in mean skill level of a cultural trait under different versions of direct biased oblique cultural transmission?
How does increasing the proportion of directly biased oblique transmission relative to vertical transmission affect the effective population size of a culturally transmitted trait in the presence or absence of natural selection?
Holding all else constant, does the presence of at least some vertical transmission (in addition to direct biased oblique transmission) require a larger population in order to support adaptive cultural evolution (i.e., a positive rate of change in mean skill level)?

ENTITIES, STATE VARIABLES, AND SCALES
Agents represent social learners.  Each agent possesses four state variables: age, _x_, times-taught, and parent. Age=0 signifies that the agent is a member of the naïve (or learner) generation. Naïve agents have not yet acquired a value for _x_, and thus naïve agents cannot serve as teachers. Age=1 signifies that the agent is a member of the parent (or teacher) generation. Only members of the parent generation can serve as parents and/or teachers. _x_ is a floating point value that can be thought of as the skill level of a culturally transmitted trait (as per Henrich 2004). Times-taught is an integer representing the number of times that the agent served as a teacher when a member of the parent generation. Each agent also has a variable, cleverly called “parent,” that allows it to remember and identify its biological parent.

Global variables include: _N_, seed, natural-selection, xMax, _z_, direct-biased-version, alpha, and beta. _N_ is census population size. Seed provides the integer used to initialize the random number generator at the start of each simulation run. When natural-selection=false, there is no natural selection in the model. When natural-selection=true, _x_ is under natural selection. The maximum _x_ value in the parent generation is recorded in xMax at the start of each time step. The probability that a naïve agent will acquire _x_ via oblique cultural transmission rather than via vertical transmission is given by _z_. As explained in the text (and below), the model allows for two different versions of directly biased oblique cultural transmission. In Shennan’s version, the naïve agent attempts to copy the highest _x_ value displayed among 5 randomly chosen members of the parent generation, excluding the biological parent of the naïve learner. In Henrich’s version, the naïve agent attempts to copy the highest _x_ displayed among the entire parent generation. The Gumbel distribution is characterized by two parameters: alpha and beta. Alpha represents the difficulty of precisely copying the target value of _x_. Beta represents the variation (or spread) that results from attempting to copy the target value. Please see Henrich (2004) for more discussion of alpha and beta, including a helpful illustration. 

Each tick represents one discrete, non-overlapping “generation” of social learning, whereby every member of the naïve generation has a chance to acquire its _x_ value by learning from the parent generation. The model has no spatial scale. Although all agents have spatial coordinates (xcor and ycor), the coordinates are assigned randomly in all cases and at no point are they used in the model.


PROCESS OVERVIEW AND SCHEDULING
Each time step includes the following stages in the following order.  Note that all agents complete each stage before any agents begin the next one.

1. Age: The _N_ agents present at the beginning of the time step move from the naïve generation to the parent generation by changing their state variable, age, from 0 to 1.

2. Create naïve generation / vertical cultural transmission: Members of the parent generation (age=1) give rise to _N_ naïve agents (age=0) either in the presence or absence of natural selection. During this process each offspring inherits its parent's _x_ as its target value through vertical transmission.

3. Directly biased oblique cultural transmission: with probability _z_, a learner replaces its target value with the _x_ value transmitted from some member of the parent generation via either Shennan's or Henrich's form of directly biased oblique cultural transmission.  Finally, the offspring adopts its _x_ value from the Gumbel distribution "anchored" to its target value.

4. Update data: compile data from the current time step.

5. Cull parent generation: all members of the parent generation (age=1) are removed from the simulation.

6. Plot a simple line graph of the mean and maximum _x_ values in the population at the end of the time step.

When using the experiments provided in BehaviorSpace, each simulation ends after 1000 time steps. Summary data are collected at that time.


DESIGN CONCEPTS
Basic principles
Naïve individuals acquire a continuous trait (_x_) via cultural transmission from the experienced, or teacher, generation. A proportion 1-_z_ (on average) of naïve agents obtains _x_ via vertical transmission while a proportion _z_ (on average) of agents obtains _x_ via one of two forms of direct biased oblique cultural transmission. Census population size remains constant throughout the simulation run. Noise in cultural transmission (both vertical and oblique) is defined by the Gumbel distribution, alpha, and beta.

Objective
The basic objective of each agent is to acquire _x_ through social learning. Under some forms of cultural transmission, such as directly biased oblique transmission, the objective is to copy the highest _x_ value among those known to the agent.

Sensing
Under vertical transmission, each member of the naïve generation learns from its parent.  In this case, each agent can only sense its biological parent as a potential teacher. However, under directly biased oblique transmission, each naïve agent learns from an agent chosen out of a set of potential teachers. Under Shennan’s version of directly biased oblique transmission, each member of the naïve generation has a set of potential teachers composed of a randomly chosen subset of 5 members of the parent generation, excluding the naïve agent’s biological parent.  Under Henrich’s version of directly biased oblique cultural transmission, each naive agent learns from the member of the parent generation that displays the highest _x_ (i.e., the potential set of teachers includes the entire parental generation).  

Interaction
Agents with age=0 interact with their parents and teachers. Naïve agents ask their teachers to increment times-taught to reflect cultural transmission of _x_. A naïve agent who learns obliquely from a teacher rather than vertically from its parent asks its parent to decrease by 1 its times-taught to reflect the fact that the naïve agent's target value is no longer its parent's _x_ value. Agents do not interact with the physical environment.

Learning
Naïve agents (age=0) learn socially by attempting to copy the _x_ value displayed by a teacher.  Transmission is imperfect.  The noise in learning is defined by the Gumbel distribution and two parameters: alpha and beta.

Stochasticity
There are many stochastic processes in the model. The Gumbel distribution provides stochastic “noise” in social learning. Each naïve agent compares a real value drawn from a uniform distribution bound by 0 and 1 to _z_, which represents the probability (per agent) of engaging in directly biased oblique transmission instead of vertical transmission. Under Shennan’s version of directly biased oblique cultural transmission, 5 possible teachers are chosen randomly from the parent generation (excluding the biological parent of ego). In the presence of natural selection, each potential parent (a member of the parent generation chosen at random and with replacement) compares its relative fitness to a real value chosen randomly from a uniform distribution bound by 0 and 1. In the absence of natural selection, parents are chosen randomly and with replacement from the parent generation. As a result, although all members of the parent generation have the same expected number of offspring (1) in the absence of natural selection, the actual number of offspring per member of the parent generation is Poisson distributed with a mean and standard deviation of 1.

Collectives
There are 3 different agent collectives in the model. The parent generation is comprised of agents with age=1.  The naïve generation is comprised of agents with age=0.  Under Shennan’s version of directly biased oblique cultural transmission, each naïve agent draws its teacher from a third type of collective, called possible-teachers.  Possible-teachers refers to a subset of the parent generation composed of 5 randomly chosen individuals excluding the naïve agent’s biological parent. Note that this means that the size of the possible-teachers collective is just 4 rather than 5 when _N_=5. For _N_>5, each naïve agent randomly draws 5 non-biological-parent members of the parent generation. Members of the parent generation can be included in more than one naïve individual’s possible-teachers collective.

Observation
Data are “tallied” and displayed at the end of each time step (some of these data are then collected by BehaviorSpace after 1000 time steps). At the end of each tick, the following data are collected: the number of individuals in the parent generation that served as a teacher at least once during the time step, the mean number of times that each member of the parent generation served as a teacher, and the variance in the number of times that each member of the parent generation served as a teacher. Running “tallies” or sums are kept for each and for each an average is calculated by dividing the running sum by the number of ticks elapsed. It is the sums averaged over 1000 ticks that are collected at the end of each simulation run. To calculate the rate of change per generation in mean skill level, I divide the population mean of _x_ after tick 1000 by 1000.


INITIALIZATION
Each simulation run is initialized with a population of _N_ social learners, each of which displays _x_=0, age=0, times-taught=0, and a randomly assigned spatial coordinate. Table 1 provides the parameter values used in the paper.

Table 1. Parameter values used in the experimental design employed in Premo (2016).
_____________________________________________________________
beta .............................. 1
alpha ............................. 1, 2, 3, 4, 5, 6
_z_ ................................... 0, 0.2, 0.4, 0.6, 1
_N_  .................................. 5, 15, 25, 35, 45, 55, 65, 75, 85, 95, 105
natural-selection .............. True, False
direct-biased-version ........ Shennan, Henrich
seed .............................. 1-20
_____________________________________________________________

INPUT DATA
The model does not make use of input files.

SUBMODELS
1 vertical-cultural-transmission
This submodel is responsible for creating the naïve generation of _N_ social learners and passing _x_ through vertical transmission at the same time. Members of the parent generation reproduce asexually until _N_ new agents have been created. While there are fewer than _N_ naïve agents, a member of the parent population is sampled (with replacement). This agent is given the opportunity to reproduce. Note that reproduction can occur in the absence of natural selection (natural-selection=false) or in the presence of natural selection (natural-selection=true). 

In the absence of natural selection, the sampled individual reproduces with probability 1. After reproduction, the sampled individual is returned to the population and the process described above is repeated until _N_ naïve social learners have been created. Note that the same agent can be chosen to reproduce more than once and that not all agents will be chosen due to the sampling error introduced by randomly drawing from a finite population.

In the presence of natural selection, the probability that the sampled agent reproduces is given by its relative individual fitness. Individual fitness is scaled relative to xMax, the maximum _x_ value displayed in the parent generation during that time step. Let _xi_ represent the sampled agent i’s _x_ value. Following Shennan (2001), the relative individual fitness of the _i_ th agent is exp(_xi_ – xMax). If a real number chosen randomly from a uniform distribution bound by 0 and 1 is less than the agent’s fitness, then the agent reproduces. If the real number is greater than the individual’s relative fitness, then the agent does not reproduce. In either case, the sampled individual is placed back into the population and the process described above is repeated until _N_ naïve social learners have been created.

Each offspring is given an age=0, a random spatial coordinate, and memory of its biological parent. Each offspring also automatically inherits its parent's _x_ value as its target value (at least for the time being).


2 directly-biased-cultural-transmission
This submodel is responsible for the transmission of _x_ values via directly biased oblique cultural transmission. Recall that _z_ provides the probability (per naïve agent) of acquiring _x_ via directly biased oblique transmission rather than vertical transmission. If a real number chosen randomly from a uniform distribution bound by 0 and 1 is less than _z_, then the naïve agent will learn _x_ via directly biased oblique transmission. 

If direct-biased-version=Shennan, then the naïve individual must go about selecting its teacher from the parent generation. According to Shennan’s (2001) version of directly biased oblique transmission, each naïve individual tries to copy the highest _x_ value displayed among a randomly chosen subset of 5 members of the parent generation, excluding the naïve individual’s biological parent. After first removing its biological parent from consideration, the naïve individual randomly chooses 5 agents from the _N_-1 remaining members of the parent generation to serve as members in its subset of possible-teachers. The naïve individual then selects the individual that displays the highest _x_ value among the members of its possible-teachers collective to serve as its teacher. 

If direct-biased-version=Henrich, directly biased oblique transmission is even simpler. Under Henrich’s version of directly biased oblique transmission, naïve learners are able to attempt to copy the member of the parent generation who displays the maximum value of _x_. 

The final component of this submodel deals with copying error--the imperfect inference or “noise” involved in cultural transmission. Note that copying error is operationalized the same regardless of whether the target value is obtained via directly biased oblique transmission or vertical transmission. In both cases, the _x_ that is ultimately adopted by the naïve learner is a function of the target value it is attempting to copy (i.e., the target value is the _x_ displayed by its teacher) and the Gumbel distribution characterized by alpha and beta (again, see Henrich [2004]). For example, if the target value is 1.876, the _x_ value the naïve learner will ultimately adopt is generated by: ((1.876 - alpha) - (beta * ln(random-exponential 1))).


REFERENCES CITED
Grimm, Volker, et al. (2010) The ODD protocol: a review and first update. _Ecological Modelling_ 221:2760-2768.

Henrich, Joseph (2004) Demography and cultural evolution: how adaptive cultural processes can produce maladaptive losses: the Tasmanian case. _American Antiquity_ 69:197-214.

Premo, L. S. (2016) Effective population size and the effects of demography on cultural diversity and technological complexity. _American Antiquity_, in press.

Shennan, Stephen J. (2001) Demography and cultural innovation: a model and its implications for the emergence of modern human culture. _Cambridge Archaeological Journal_ 11:5-16.



## CONTACT INFORMATION
This model was programmed during the spring of 2015 by Luke Premo of the Department of Anthropology, Washington State University and the Department of Human Evolution, Max Planck Institute for Evolutionary Anthropology.

One of the best things about computer simulation programs is that they can often be improved with the help of other researchers. The more sets of eyes that pass over the code, the better. So, please, have a look at the source code. Any comments, questions, or corrections are always welcome. You can contact me at:

Luke Premo  
Department of Anthropology
Washington State University
Pullman, WA 99164-4910 

luke.premo at wsu dot edu
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment1_shennan_with_natural_selection" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>meanMeank</metric>
    <metric>meanVk</metric>
    <metric>meanNumTeachers</metric>
    <metric>mean [x] of turtles</metric>
    <metric>(N - 1) / meanVk</metric>
    <enumeratedValueSet variable="direct-biased-version">
      <value value="&quot;Shennan&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="natural-selection">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="z">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="5"/>
      <value value="15"/>
      <value value="25"/>
      <value value="35"/>
      <value value="45"/>
      <value value="55"/>
      <value value="65"/>
      <value value="75"/>
      <value value="85"/>
      <value value="95"/>
      <value value="105"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="20"/>
  </experiment>
  <experiment name="experiment2_henrich_without_natural_selection" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>meanMeank</metric>
    <metric>meanVk</metric>
    <metric>meanNumTeachers</metric>
    <metric>mean [x] of turtles</metric>
    <metric>(N - 1) / meanVk</metric>
    <enumeratedValueSet variable="direct-biased-version">
      <value value="&quot;Henrich&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="natural-selection">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="z">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="5"/>
      <value value="15"/>
      <value value="25"/>
      <value value="35"/>
      <value value="45"/>
      <value value="55"/>
      <value value="65"/>
      <value value="75"/>
      <value value="85"/>
      <value value="95"/>
      <value value="105"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="20"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
